"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var camelCase = require('lodash/camelCase');
var getByPath = require('lodash/get');
var setByPath = require('lodash/set');
var bignumber_js_1 = require("bignumber.js");
/**
 * iterates over array/object and converts all keys to camelCase
 * @param data input object or array
 *
 * @see https://lodash.com/docs/#camelCase
 *
 */
function camelCaseProps(data) {
    // guarding against empty values
    if (!data) {
        return data;
    }
    var returnArray = Array.isArray(data);
    var response = returnArray ? [] : {};
    Object.entries(data).forEach(function (_a) {
        var key = _a[0], value = _a[1];
        if (typeof value !== 'object' || !value) {
            response[camelCase(key)] = value;
            return;
        }
        var entries = Object.entries(value);
        if (entries.length > 0) {
            response[camelCase(key)] = camelCaseProps(value);
            return;
        }
        response[camelCase(key)] = value;
    });
    return response;
}
exports.camelCaseProps = camelCaseProps;
/**
 * Casts object/array items to BigNumber
 * keys support lodash path notation
 * @param data input object or array
 * @param keys keys for processing or all items if not defined
 *
 * @see https://lodash.com/docs/#get
 *
 */
function castToBigNumber(data, keys) {
    var returnArray = Array.isArray(data);
    if (typeof keys === 'undefined') {
        keys = Object.keys(data);
    }
    var response = returnArray ? [] : {};
    keys.forEach(function (key) {
        var item = getByPath(data, key);
        var res;
        if (typeof item === 'undefined') {
            return;
        }
        if (Array.isArray(item)) {
            res = castToBigNumber(item);
            setByPath(response, key, res);
            return;
        }
        res = new bignumber_js_1.default(item);
        setByPath(response, key, res);
    });
    return response;
}
exports.castToBigNumber = castToBigNumber;
/**
 * Casts object/array BigNumber items to strings for readability
 * @param data input object or array
 * @param keys keys for processing or all items if not defined
 *
 */
function castToString(data, keys) {
    var returnArray = Array.isArray(data);
    if (typeof keys === 'undefined') {
        keys = Object.keys(data);
    }
    var response = returnArray ? [] : {};
    keys.forEach(function (key) {
        var item = data[key];
        if (typeof item === 'undefined') {
            return;
        }
        if (Array.isArray(item)) {
            response[key] = castToString(item);
            return;
        }
        if (!(item instanceof bignumber_js_1.default)) {
            response[key] = item;
            return;
        }
        response[key] = item.toString();
    });
    return response;
}
exports.castToString = castToString;
//# sourceMappingURL=utils.js.map